pub enum SqlValue {
Null,
Boolean(bool),
Integer(i64),
Unsigned(u64),
Float(f64),
TimestampMillis(i64),
Text(String),
Bytes(Vec<u8>),
List(Vec<Self>),
Other(String),
}Expand description
One SQL value independent of DataFusion and Arrow versions.
Variants
Null
SQL NULL.
Boolean(bool)
Boolean.
Integer(i64)
Signed integer normalized to 64 bits.
Unsigned(u64)
Unsigned integer normalized to 64 bits.
Float(f64)
Floating-point value normalized to 64 bits.
TimestampMillis(i64)
Milliseconds since the Unix epoch.
Text(String)
UTF-8 text.
Bytes(Vec<u8>)
Arbitrary bytes.
List(Vec<Self>)
Variable-length list. Corium cardinality-many columns use unique, deterministically ordered lists with set semantics.
Other(String)
Text rendering of an engine value not yet represented structurally.